/**
* \file temp.c
* @brief Funktionsumfang zum Temperatursensor DS75LV
*/

#include "max127.h"


/**
* Initialisiert die TWI Schnittstelle und den ADC MAX127
* @return gibt an, ob ein Timeout ausgelst wurde (=1 Timeout und somit Fehler, =0 alles i.O.)
*/
void max127_init()
{
	TWI_init();
}

/**
* Liest die Spannung des ADC MAX127 aus
* @param channel Kanal whlen (0..7)
* @param range gint Spannungsbereich an (0 -> 0..5V, 1 -> +-5V, 2 -> 0..10V, 3 -> +-10V)
* @param value Pointer auf Speicherstelle fr ermittelten Spannungswert
* @return gibt an, ob ein Timeout ausgelst wurde (=1 Timeout und somit Fehler, =0 alles i.O.)
*/
uint8_t get_adc(uint8_t channel,uint8_t range, int16_t* value)
{	uint8_t error=0;
	uint8_t vor=0;
	uint8_t nach=0;
	uint8_t tmp=0;	
	
	error=TWI_start(0b0101000,TWIwrite);

	tmp = 0x80 | ((channel & 0x07 )<<4) | ((range & 0x03)<<2);	//Controle Byte nach Datenblatt zusammensetzen

	if (error!=true) {error=TWI_write(tmp);}					//Controle Byte --> Configuration
	TWI_stop();
	if (error!=true) {error=TWI_start(0b1001000,TWIread);}

	if (error!=true) {error=TWI_read_ack(&vor);}
	if (error!=true) {error=TWI_read_nack(&nach);}	

	TWI_stop();
	*value = 0;
	*value = ((*value) | (((int16_t)vor) <<4)) | ((((int16_t)nach)>>4) & 0x000F);
	// falls ermittelter Wert negativ ist, muss mit "1en" aufgefllt werden
	if ((vor & 0x80)==0x80) {
		*value = *value | 0xF000; 
	}
	return error;
}



